'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.parseUnit = exports.toPx = exports.pxTo = undefined;

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _objectGet = require('object-get');

var _objectGet2 = _interopRequireDefault(_objectGet);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

var DesignSystem = function () {
  function DesignSystem(system, options) {
    _classCallCheck(this, DesignSystem);

    var defaultOptions = {
      fontSizeUnit: undefined
    };
    this.opts = Object.assign({}, defaultOptions, options);
    this.ds = system;
  }

  _createClass(DesignSystem, [{
    key: 'multiply',
    value: function multiply(initial, multiplier) {
      var initialVal = void 0;
      if (typeof initial === 'string') {
        initialVal = parseFloat(this.get(initial));
      } else {
        initialVal = initial;
      }
      return initialVal * multiplier;
    }
  }, {
    key: 'get',
    value: function get(value) {
      var obj = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : this.ds;

      return (0, _objectGet2.default)(obj, value);
    }
  }, {
    key: 'bp',
    value: function bp(_bp) {
      return this.get(_bp, this.ds.breakpoints);
    }
  }, {
    key: 'z',
    value: function z(_z) {
      return this.get(_z, this.ds.zIndex);
    }
  }, {
    key: 'fontSize',
    value: function fontSize(size) {
      var output = '' + this.get(size, this.ds.type.sizes);
      var baseFontSize = parseFloat(this.ds.type.baseFontSize);

      // Don't convert the value if we don't have to
      if (parseUnit(output) === this.opts.fontSizeUnit) {
        return output;
      }

      // Convert font-size to the specified unit
      switch (this.opts.fontSizeUnit) {
        case 'rem':
          return pxTo(output, baseFontSize, 'rem');
        case 'em':
          return pxTo(output, baseFontSize, 'em');
        case 'px':
          return toPx(output, baseFontSize);
        default:
          return output;
      }
    }
  }, {
    key: 'fs',
    value: function fs(size) {
      return this.fontSize(size);
    }
  }, {
    key: 'spacing',
    value: function spacing() {
      var index = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 0;

      return this.ds.spacing.scale[index] + 'px';
    }
  }, {
    key: 'space',
    value: function space(index) {
      return this.spacing(index);
    }
  }, {
    key: 'color',
    value: function color(hue) {
      var value = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 'base';

      return this.ds.colors.colorPalette[hue][value];
    }
  }, {
    key: 'brand',
    value: function brand(color) {
      return this.get(color, this.ds.colors.brand);
    }
  }]);

  return DesignSystem;
}();

// Converts px to rem/em


exports.default = DesignSystem;
var pxTo = exports.pxTo = function pxTo(value) {
  var base = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 16;
  var unit = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 'rem';
  return '' + parseFloat(value) / base + unit;
};

// Converts rem/em to px
var toPx = exports.toPx = function toPx(value) {
  var base = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 16;
  return parseFloat(value) * base + 'px';
};

var parseUnit = exports.parseUnit = function parseUnit(str) {
  return str.trim().match(/[\d.\-\+]*\s*(.*)/)[1] || '';
};